jactorch.nn.gumbel\_softmax.functional
======================================

.. automodule:: jactorch.nn.gumbel_softmax.functional

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      SoftmaxImplmentation
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      general_softmax
      greedy_softmax
      gumbel_softmax
   
   

   
   
   








.. rubric:: Class SoftmaxImplmentation
.. autoclass:: SoftmaxImplmentation
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: general_softmax

.. autofunction:: greedy_softmax

.. autofunction:: gumbel_softmax


